@@ -1,7 +1,7 @@
 use {
     super::*,
     crate::{
-        app::{Selection, SelInfo, SelectionType},
+        app::*,
         errors::ConfError,
         keys,
         path::{self, PathAnchor},
@@ -58,6 +58,10 @@ pub struct Verb {
     /// if true (default) verbs are directly executed when
     /// triggered with a keyboard shortcut
     pub auto_exec: bool,
+
+    /// whether to show the verb in help screen
+    /// (if we show all input related actions, the doc is unusable)
+    pub show_in_doc: bool
 }
 
 impl Verb {
@@ -100,6 +104,7 @@ impl Verb {
             needs_selection,
             needs_another_panel,
             auto_exec: true,
+            show_in_doc: true,
         })
     }
     fn update_key_desc(&mut self) {
@@ -139,6 +144,10 @@ impl Verb {
             modifiers: KeyModifiers::NONE,
         })
     }
+    pub fn no_doc(mut self) -> Self {
+        self.show_in_doc = false;
+        self
+    }
     pub fn with_description(mut self, description: &str) -> Self {
         self.description = VerbDescription::from_text(description.to_string());
         self
@@ -210,7 +219,7 @@ impl Verb {
     pub fn get_status_markdown(
         &self,
         sel_info: SelInfo<'_>,
-        other_path: &Option<PathBuf>,
+        app_state: &AppState,
         invocation: &VerbInvocation,
     ) -> String {
         let name = self.names.get(0).unwrap_or(&invocation.name);
@@ -240,10 +249,10 @@ impl Verb {
         }
 
         let builder = || {
-            ExecutionStringBuilder::from_invocation(
+            ExecutionStringBuilder::with_invocation(
                 &self.invocation_parser,
                 sel_info,
-                other_path,
+                app_state,
                 &invocation.args,
             )
         };
